
from django.http import HttpResponse

from django_tex.core import compile_template_to_pdf

class PDFResponse(HttpResponse):

    def __init__(self, content, filename=None):
        super(PDFResponse, self).__init__(content_type='application/pdf')
        self['Content-Disposition'] = 'filename="{}"'.format(filename)
        self.write(content)


def render_to_pdf(request, template_name, context=None, filename=None):
    # Request is not needed and only included to make the signature conform to django's render function
    pdf = compile_template_to_pdf(template_name, context)
    return PDFResponse(pdf, filename=filename)




from django_tex.environment import environment

def hhmm_format(value):
    total_seconds = value.total_seconds()
    hours, remainder = divmod(total_seconds, 3600)
    minutes, seconds = divmod(remainder, 60)
    return '{:n}:{:02n}'.format(hours, minutes)

def test_environment(**options):
    env = environment(**options)
    env.filters.update({
        'hhmm_format': hhmm_format,
    })
    return env




from jinja2 import Environment

from django.template.defaultfilters import register

from django_tex.filters import FILTERS as tex_specific_filters

# Django's built-in filters ...
filters = register.filters
# ... updated with tex specific filters
filters.update(tex_specific_filters)

def environment(**options):
    env = Environment(**options)
    env.filters = filters
    return env
